==> cpg-language-python-4.3.3-sources.jar: de/fraunhofer/aisec/cpg/frontends/python/PyTempFileHolder.kt <==
/*
 * Copyright (c) 2021, Fraunhofer AISEC. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *                    $$$$$$\  $$$$$$$\   $$$$$$\
 *                   $$  __$$\ $$  __$$\ $$  __$$\
 *                   $$ /  \__|$$ |  $$ |$$ /  \__|
 *                   $$ |      $$$$$$$  |$$ |$$$$\
 *                   $$ |      $$  ____/ $$ |\_$$ |
 *                   $$ |  $$\ $$ |      $$ |  $$ |
 *                   \$$$$$   |$$ |      \$$$$$   |
 *                    \______/ \__|       \______/
 *
 */
package de.fraunhofer.aisec.cpg.frontends.python

import java.nio.file.Files
import java.nio.file.Path

class PyTempFileHolder {
    // create temporary file and folder
    var pyZipOnDisk: Path = Files.createTempFile("cpg_python", ".zip")
    var pyFolder: Path = Files.createTempDirectory("cpg_python")

    protected fun finalize() {
        // clean up once no longer used
        pyZipOnDisk.toFile().delete()
        // pyFolder.toFile().deleteRecursively() // TODO
    }
}

==> cpg-language-python-6.2.2-sources.jar: de/fraunhofer/aisec/cpg/frontends/python/PyTempFileHolder.kt <==
/*
 * Copyright (c) 2021, Fraunhofer AISEC. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *                    $$$$$$\  $$$$$$$\   $$$$$$\
 *                   $$  __$$\ $$  __$$\ $$  __$$\
 *                   $$ /  \__|$$ |  $$ |$$ /  \__|
 *                   $$ |      $$$$$$$  |$$ |$$$$\
 *                   $$ |      $$  ____/ $$ |\_$$ |
 *                   $$ |  $$\ $$ |      $$ |  $$ |
 *                   \$$$$$   |$$ |      \$$$$$   |
 *                    \______/ \__|       \______/
 *
 */
package de.fraunhofer.aisec.cpg.frontends.python

import java.nio.file.Files
import java.nio.file.Path

class PyTempFileHolder {
    // create temporary file and folder
    private var pyZipOnDisk: Path = Files.createTempFile("cpg_python", ".zip")
    var pyFolder: Path = Files.createTempDirectory("cpg_python")

    protected fun finalize() {
        // clean up once no longer used
        pyZipOnDisk.toFile().delete()
        // pyFolder.toFile().deleteRecursively() // TODO
    }
}
